@@ -17,18 +17,12 @@
  * Boston, MA 02111-1307, USA.
  */
 
-using gbrainy.Core.Services;
-
 namespace gbrainy.Clients.Classical.Dialogs
 {
 	public class BuilderDialog : Gtk.Dialog
 	{
-		protected ITranslations Translations { get; private set;}
-
-		public BuilderDialog (ITranslations translations, string resourceName, string dialogName) : 
-			this ((System.Reflection.Assembly) null, resourceName, dialogName)
+		public BuilderDialog (string resourceName, string dialogName) : this (null, resourceName, dialogName)
 		{
-			Translations = translations;
 		}
 
 		public BuilderDialog (System.Reflection.Assembly assembly, string resourceName, string dialogName) : 
