@@ -22,7 +22,6 @@ using Gtk;
 using Mono.Unix;
 
 using gbrainy.Core.Main;
-using gbrainy.Core.Services;
 
 namespace gbrainy.Clients.Classical.Dialogs
 {
@@ -37,14 +36,12 @@ namespace gbrainy.Clients.Classical.Dialogs
 		[GtkBeans.Builder.Object] Gtk.RadioButton rb_medium;
 		[GtkBeans.Builder.Object] Gtk.RadioButton rb_master;
 		[GtkBeans.Builder.Object] Gtk.ComboBox themes_combobox;
-		[GtkBeans.Builder.Object] Gtk.CheckButton englishcheckbutton;
-		[GtkBeans.Builder.Object] Gtk.CheckButton loadextensionscheckbutton;
-		[GtkBeans.Builder.Object] Gtk.CheckButton usesoundscheckbutton;
+		[GtkBeans.Builder.Object] Gtk.CheckButton english_checkbutton;
 
 		const int COLUMN_VALUE = 1;
 		PlayerHistory history;
 
-		public PreferencesDialog (ITranslations translations, PlayerHistory history) : base (translations, "PreferencesDialog.ui", "preferences")
+		public PreferencesDialog (PlayerHistory history) : base ("PreferencesDialog.ui", "preferences")
 		{
 			this.history = history;
 			prefspinbutton.Value = Preferences.Get <int> (Preferences.MemQuestionTimeKey);
@@ -52,9 +49,7 @@ namespace gbrainy.Clients.Classical.Dialogs
 			maxstoredspinbutton.Value = Preferences.Get <int> (Preferences.MaxStoredGamesKey);
 			minplayedspinbutton.Value = Preferences.Get <int> (Preferences.MinPlayedGamesKey);
 			colorblindcheckbutton.Active = Preferences.Get <bool> (Preferences.ColorBlindKey);
-			englishcheckbutton.Active = Preferences.Get <bool> (Preferences.EnglishKey);
-			loadextensionscheckbutton.Active = Preferences.Get <bool> (Preferences.LoadPlugginsKey);
-			usesoundscheckbutton.Active = Preferences.Get <bool> (Preferences.SoundsKey);
+			english_checkbutton.Active = Preferences.Get <bool> (Preferences.EnglishKey);
 
 			switch ((GameDifficulty) Preferences.Get <int> (Preferences.DifficultyKey)) {
 			case GameDifficulty.Easy:
@@ -91,10 +86,6 @@ namespace gbrainy.Clients.Classical.Dialogs
 				}
 				more = store.IterNext (ref iter);
 			}
-
-			#if !MONO_ADDINS
-				loadextensionscheckbutton.Visible = false;
-			#endif
 		}
 
 		private GameDifficulty Difficulty {
@@ -133,9 +124,7 @@ namespace gbrainy.Clients.Classical.Dialogs
 			Preferences.Set <int>  (Preferences.MaxStoredGamesKey, (int) maxstoredspinbutton.Value);
 			Preferences.Set <int>  (Preferences.MinPlayedGamesKey, (int) minplayedspinbutton.Value);
 			Preferences.Set <bool> (Preferences.ColorBlindKey, colorblindcheckbutton.Active);
-			Preferences.Set <bool> (Preferences.EnglishKey, englishcheckbutton.Active);
-			Preferences.Set <bool> (Preferences.LoadPlugginsKey, loadextensionscheckbutton.Active);
-			Preferences.Set <bool> (Preferences.SoundsKey, usesoundscheckbutton.Active);
+			Preferences.Set <bool> (Preferences.EnglishKey, english_checkbutton.Active);
 
 			TreeIter iter;
 			themes_combobox.GetActiveIter (out iter);
