@@ -27,7 +27,6 @@ using System.Reflection;
 using gbrainy.Core.Main;
 using gbrainy.Core.Platform;
 using gbrainy.Core.Services;
-using gbrainy.Core.Libraries;
 using gbrainy.Clients.Classical.Dialogs;
 using gbrainy.Clients.Classical.Widgets;
 
@@ -51,6 +50,7 @@ namespace gbrainy.Clients.Classical
 		[GtkBeans.Builder.Object] Gtk.Button tip_button;
 		[GtkBeans.Builder.Object] Gtk.Button next_button;
 		[GtkBeans.Builder.Object] Gtk.Statusbar statusbar;
+		[GtkBeans.Builder.Object] Gtk.MenuBar menubar;
 		[GtkBeans.Builder.Object] Gtk.MenuItem pause_menuitem;
 		[GtkBeans.Builder.Object] Gtk.MenuItem finish_menuitem;
 		[GtkBeans.Builder.Object] Gtk.MenuItem newgame_menuitem;
@@ -68,18 +68,17 @@ namespace gbrainy.Clients.Classical
 
 		GameDrawingArea drawing_area;
 		GameSession session;
+		bool low_res;
 		bool full_screen;
 		GameSession.Types initial_session;
-		static bool pluggins_loaded;
 
 		public readonly int MIN_TRANSLATION = 80;
 
-		public GtkClient (ITranslations translations)
+		public GtkClient ()
 		{
-			Translations = translations;
 			if (Preferences.Get <bool> (Preferences.EnglishKey) == false)
 			{
-				translations.Init ("gbrainy", Defines.GNOME_LOCALE_DIR);
+				Catalog.Init ("gbrainy", Defines.GNOME_LOCALE_DIR);
 			}
 
 			Unix.FixLocaleInfo ();
@@ -94,16 +93,13 @@ namespace gbrainy.Clients.Classical
 			set { initial_session = value; }
 		}
 
-		ITranslations Translations {get; set;}
-
 		public void Initialize ()
 		{
-			session = new GameSession (Translations);
-			
+			session = new GameSession ();
 			GameManagerPreload (session.GameManager);
-			Console.WriteLine (session.GameManager.GetGamesSummary (Translations));
+			Console.WriteLine (session.GameManager.GetGamesSummary ());
 
-			session.PlayList.ColorBlind = Preferences.Get <bool> (Preferences.ColorBlindKey);
+			session.GameManager.ColorBlind = Preferences.Get <bool> (Preferences.ColorBlindKey);
 			session.DrawRequest += SessionDrawRequest;
 			session.UpdateUIElement += SessionUpdateUIElement;
 			session.SynchronizingObject = new GtkSynchronize ();
@@ -117,12 +113,7 @@ namespace gbrainy.Clients.Classical
 			gm.LoadAssemblyGames (Defines.GAME_ASSEMBLY);
 			gm.LoadVerbalAnalogies (System.IO.Path.Combine (Defines.DATA_DIR, Defines.VERBAL_ANALOGIES));
 			gm.LoadGamesFromXml (System.IO.Path.Combine (Defines.DATA_DIR, Defines.GAMES_FILE));
-
-			if (Preferences.Get <bool> (Preferences.LoadPlugginsKey))
-			{			
-				gm.LoadPlugins ();
-				pluggins_loaded = true;
-			}
+			gm.LoadPlugins ();
 		}
 
 		void BuildUI ()
@@ -132,7 +123,7 @@ namespace gbrainy.Clients.Classical
 			GtkBeans.Builder builder = new GtkBeans.Builder ("gbrainy.ui");
 			builder.Autoconnect (this);
 
-			show_toolbar = Preferences.Get <bool> (Preferences.ToolbarShowKey) == true;
+			show_toolbar = Preferences.Get <bool> (Preferences.ToolbarShowKey) == true && low_res == false;
 
 			// Toolbar creation
 			toolbar = new Widgets.Toolbar (main_hbox, framework_vbox);
@@ -149,6 +140,14 @@ namespace gbrainy.Clients.Classical
 			drawing_area.Drawable = session;
 			GameSensitiveUI ();
 
+			// For low resolutions, hide the toolbar and made the drawing area smaller
+			if (drawing_area.Screen.Width> 0 && drawing_area.Screen.Height > 0) {
+				if (drawing_area.Screen.Height < 700) {
+					drawing_vbox.HeightRequest = 350;
+					low_res = true;
+				}
+			}
+
 			EventBox eb = new EventBox (); // Provides a window for drawing area windowless widget
 
 			eb.Events = Gdk.EventMask.PointerMotionMask;
@@ -159,7 +158,7 @@ namespace gbrainy.Clients.Classical
 			eb.MotionNotifyEvent += OnMouseMotionEvent;
 			eb.ButtonPressEvent += OnHandleButtonPress;
 
-			show_toolbar = Preferences.Get <bool> (Preferences.ToolbarShowKey) == true;
+			show_toolbar = Preferences.Get <bool> (Preferences.ToolbarShowKey) == true && low_res == false;
 
 			// We only disable the Arrow if we are going to show the toolbar.
 			// It has an impact on the total window width size even if we do not show it
@@ -191,11 +190,7 @@ namespace gbrainy.Clients.Classical
 
 		#if MONO_ADDINS
 			extensions_menuitem.Activated += delegate (object sender, EventArgs ar) 
-			{
-				if (pluggins_loaded == false)
-				{			
-					session.GameManager.LoadPlugins ();
-				}
+			{ 
 				Mono.Addins.Gui.AddinManagerWindow.Run (app_window);
 				GameManagerPreload (session.GameManager);
 				CustomGameDialog.Clear ();
@@ -424,13 +419,9 @@ namespace gbrainy.Clients.Classical
 
 			correct = session.ScoreGame (answer_entry.Text);
 			if (correct)
-			{
-				answer = Translations.GetString ("Congratulations.");
-			}
+				answer = Catalog.GetString ("Congratulations.");
 			else
-			{
-				answer = Translations.GetString ("Incorrect answer.");
-			}			
+				answer = Catalog.GetString ("Incorrect answer.");
 
 			session.EnableTimer = false;
 			answer_entry.Text = String.Empty;
@@ -443,11 +434,6 @@ namespace gbrainy.Clients.Classical
 			ActiveInputControls (true);
 			next_button.GrabFocus ();
 			drawing_area.QueueDraw ();
-
-			if (Preferences.Get <bool> (Preferences.SoundsKey))
-			{
-				Unix.PlaySound(app_window.Handle, System.IO.Path.Combine(Defines.DATA_DIR, correct ? "right.oga" : "wrong.oga"));
-			}
 		}
 
 		void OnQuit (object sender, EventArgs args)
@@ -483,25 +469,25 @@ namespace gbrainy.Clients.Classical
 		void OnNewGame (GameSession.Types type)
 		{
 			// If the translation is lower than MIN_TRANSLATION explain that running the English version is an option
-			if (ShouldShowTranslationWarning ())
-				ShowTranslationWarning ();
+			if (ShowTranslationWarning ())
+				Translations ();
 
 			session.Type = type;
 			session.New ();
 			GetNextGame ();
 			GameSensitiveUI ();
-			UpdateSolution (Translations.GetString ("Once you have an answer type it in the \"Answer:\" entry box and press the \"OK\" button."),
+			UpdateSolution (Catalog.GetString ("Once you have an answer type it in the \"Answer:\" entry box and press the \"OK\" button."),
 				GameDrawingArea.SolutionType.Tip);
 			UpdateStatusBar ();
 		}
 
-		public bool ShouldShowTranslationWarning ()
+		public bool ShowTranslationWarning ()
 		{
 			// Notify the user once per version only
 			if (String.Compare (Preferences.Get <string> (Preferences.EnglishVersionKey), Defines.VERSION, 0) == 0)
 				return false;
 
-			int percentage = Translations.TranslationPercentage;
+			int percentage = ServiceLocator.Instance.GetService <ITranslations> ().TranslationPercentage;
 			if (percentage > 0 && percentage < MIN_TRANSLATION)
 			{
 				Preferences.Set <string> (Preferences.EnglishVersionKey, Defines.VERSION);
@@ -512,7 +498,7 @@ namespace gbrainy.Clients.Classical
 			return false;
 		}
 
-		void ShowTranslationWarning ()
+		void Translations ()
 		{		
 			HigMessageDialog dlg;
 	
@@ -520,8 +506,8 @@ namespace gbrainy.Clients.Classical
 				Gtk.DialogFlags.DestroyWithParent,
 				Gtk.MessageType.Warning,
 				Gtk.ButtonsType.Ok,
-				Translations.GetString ("The level of translation of gbrainy for your language is low."),
-				Translations.GetString ("You may be exposed to partially translated games making it more difficult to play. If you prefer to play in English, there is an option for doing so in gbrainy's Preferences."));
+				Catalog.GetString ("The level of translation of gbrainy for your language is low."),
+				Catalog.GetString ("You may be exposed to partially translated games making it more difficult to play. If you prefer to play in English, there is an option for doing so in gbrainy's Preferences."));
 		
 			try {
 	 			dlg.Run ();
@@ -549,7 +535,7 @@ namespace gbrainy.Clients.Classical
 		{
 			PdfExportDialog pdf;
 
-			pdf = new PdfExportDialog (session.GameManager, Translations);
+			pdf = new PdfExportDialog ();
 			pdf.Run ();
 			pdf.Destroy ();
 		}
@@ -558,10 +544,10 @@ namespace gbrainy.Clients.Classical
 		{
 			PreferencesDialog dialog;
 
-			dialog = new PreferencesDialog (Translations, session.PlayerHistory);
+			dialog = new PreferencesDialog (session.PlayerHistory);
 			if ((Gtk.ResponseType) dialog.Run () == ResponseType.Ok) {
 				session.Difficulty = (GameDifficulty) Preferences.Get <int> (Preferences.DifficultyKey);
-				session.PlayList.ColorBlind = Preferences.Get <bool> (Preferences.ColorBlindKey);
+				session.GameManager.ColorBlind = Preferences.Get <bool> (Preferences.ColorBlindKey);
 
 				if (dialog.NewThemeSet == true)
 					drawing_area.ReloadBackground ();
@@ -573,7 +559,7 @@ namespace gbrainy.Clients.Classical
 		{
 			CustomGameDialog dialog;
 
-			dialog = new CustomGameDialog (Translations, session);
+			dialog = new CustomGameDialog (session.GameManager);
 			dialog.Run ();
 			dialog.Destroy ();
 
@@ -617,12 +603,12 @@ namespace gbrainy.Clients.Classical
 			if (pause) {
 				drawing_area.Paused = false;
 				toolbar.PauseButton.StockId = "pause";
-				toolbar.PauseButton.Label = Translations.GetString ("Pause");
+				toolbar.PauseButton.Label = Catalog.GetString ("Pause");
 				ActiveInputControls (true);
 			} else {
 				drawing_area.Paused = true;
 				toolbar.PauseButton.StockId = "resume";
-				toolbar.PauseButton.Label = Translations.GetString ("Resume");
+				toolbar.PauseButton.Label = Catalog.GetString ("Resume");
 				ActiveInputControls (false);
 			}
 			UpdateStatusBar ();
@@ -699,7 +685,7 @@ namespace gbrainy.Clients.Classical
 		{
 			PlayerHistoryDialog dialog;
 
-			dialog = new PlayerHistoryDialog (Translations, session.PlayerHistory);
+			dialog = new PlayerHistoryDialog (session.PlayerHistory);
 			dialog.Run ();
 			dialog.Destroy ();
 		}
@@ -718,7 +704,7 @@ namespace gbrainy.Clients.Classical
 
 		void OnExtending (object sender, EventArgs args)
 		{
-			Process.Start ("https://wiki.gnome.org/Apps/gbrainy/Extending");
+			Process.Start ("http://live.gnome.org/gbrainy/Extending");
 		}
 
 		static void InitCoreLibraries ()
@@ -746,14 +732,13 @@ namespace gbrainy.Clients.Classical
 			}
 
 			DateTime start_time = DateTime.Now;
-			ITranslations translations = new TranslationsCatalog ();
 
 			InitCoreLibraries ();
 
-			GtkClient app = new GtkClient (translations);
+			GtkClient app = new GtkClient ();
 			CommandLine.Version ();
 
-			CommandLine line = new CommandLine (translations, args);
+			CommandLine line = new CommandLine (args);
 			line.Parse ();
 
 			if (line.Continue == false)
@@ -763,9 +748,9 @@ namespace gbrainy.Clients.Classical
 
 			app.Initialize ();
 			// Set RandomOrder before setting the custom list then it has effect of custom games
-			app.Session.PlayList.RandomOrder = line.RandomOrder;
+			app.Session.GameManager.RandomOrder = line.RandomOrder;
 			if (line.PlayList.Length > 0) {
-				app.Session.PlayList.PlayList = line.PlayList;
+				app.Session.GameManager.PlayList = line.PlayList;
 				app.InitialSessionType = GameSession.Types.Custom;
 			}
 			app.ProcessDefaults ();
