@@ -21,6 +21,7 @@ using System;
 using System.Collections.Generic;
 
 using gbrainy.Core.Toolkit;
+using gbrainy.Core.Services;
 
 namespace gbrainy.Core.Main.Verbal
 {
@@ -36,7 +37,7 @@ namespace gbrainy.Core.Main.Verbal
 		}
 
 		public override string Name {
-			get { return String.Format (Translations.GetString ("Pair of words #{0}"), Variant);}
+			get { return String.Format (ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Pair of words #{0}"), Variant);}
 		}
 
 		public override Dictionary <int, Analogy> List {
@@ -51,13 +52,13 @@ namespace gbrainy.Core.Main.Verbal
 				if (Current.answers == null)
 					return Current.question;
 
-				string ques = String.Format (Translations.GetString (
+				string ques = String.Format (ServiceLocator.Instance.GetService <ITranslations> ().GetString (
 					"Given the relationship between the two words below, which word has the same relationship to '{0}'?"),
 					sample);
 
 				// Translators: {0} is replaced by a question and {1} by the possible valid answers
 				// E.g.: What is the correct option? Answer A, B, C or D.
-				return String.Format (Translations.GetString ("{0} Answer {1}."),
+				return String.Format (ServiceLocator.Instance.GetService <ITranslations> ().GetString ("{0} Answer {1}."),
 					ques, Answer.GetMultiOptionsPossibleAnswers (Current.answers.Length));
 			}
 		}
@@ -83,7 +84,7 @@ namespace gbrainy.Core.Main.Verbal
 			Answer.CheckAttributes |= GameAnswerCheckAttributes.MultiOption;
 			Answer.Correct = Answer.GetMultiOption (Current.right);
 
-			Container container = new Container (DrawAreaX,  DrawAreaY + 0.25, 0.8, Current.answers.Length * 0.15);
+			Container container = new Container (DrawAreaX + 0.1, 0.50, 0.5, Current.answers.Length * 0.15);
 			AddWidget (container);
 	
 			for (int i = 0; i <  Current.answers.Length; i++)
@@ -100,7 +101,7 @@ namespace gbrainy.Core.Main.Verbal
 					int n = (int) e.Data;
 
 					e.Context.MoveTo (0.05, 0.02);
-					e.Context.ShowPangoText (String.Format (Translations.GetString ("{0}) {1}"), Answer.GetMultiOption (n), Current.answers[n].ToString ()));
+					e.Context.ShowPangoText (String.Format (ServiceLocator.Instance.GetService <ITranslations> ().GetString ("{0}) {1}"), Answer.GetMultiOption (n), Current.answers[n].ToString ()));
 				};
 			}
 			SetAnswerCorrectShow ();
@@ -118,11 +119,11 @@ namespace gbrainy.Core.Main.Verbal
 			gr.SetPangoLargeFontSize ();
 
 			gr.MoveTo (0.1, y + 0.12);
-			gr.ShowPangoText (Translations.GetString ("Choose one of the following:"));
+			gr.ShowPangoText (ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Choose one of the following:"));
 			gr.Stroke ();
 
 			gr.DrawTextCentered (0.5, y,
-				String.Format (Translations.GetString ("Words: {0}"), samples));
+				String.Format (ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Words: {0}"), samples));
 
 		}
 	}
