@@ -44,9 +44,8 @@ namespace gbrainy.Core.Views
 		readonly Cairo.Color desc_color = new Color (0.3, 0.3, 0.3);
 		PlayerHistory history;
 
-		public PlayerHistoryView (ITranslations translations, PlayerHistory history)
+		public PlayerHistoryView (PlayerHistory history)
 		{
-			Translations = translations;
 			this.history = history;
 			ShowLogic = ShowMemory = ShowCalculation = ShowVerbal = true;
 		}
@@ -56,7 +55,6 @@ namespace gbrainy.Core.Views
 		public bool ShowMemory { get; set; }
 		public bool ShowCalculation { get; set; }
 		public bool ShowVerbal { get; set; }
-		private ITranslations Translations { get; set; }
 
 		void DrawAxisDescription (CairoContextEx cr, double x, double y, string description)
 		{
@@ -82,7 +80,7 @@ namespace gbrainy.Core.Views
 			cr.Stroke ();
 			cr.Color = text_color;
 			cr.MoveTo (x + line_size + offset_x, y - 0.01);
-			cr.ShowPangoText (Translations.GetString ("Total"));
+			cr.ShowPangoText (ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Total"));
 			cr.Stroke ();
 
 			cr.Color = logic_color;
@@ -91,7 +89,7 @@ namespace gbrainy.Core.Views
 			cr.Stroke ();
 			cr.Color = text_color;
 			cr.MoveTo (x + line_size + offset_x, y - 0.01 + second_row);
-			cr.ShowPangoText (GameTypesDescription.GetLocalized (Translations, GameTypes.LogicPuzzle));
+			cr.ShowPangoText (GameTypesDescription.GetLocalized (GameTypes.LogicPuzzle));
 			cr.Stroke ();
 
 			x += space_hor;
@@ -101,7 +99,7 @@ namespace gbrainy.Core.Views
 			cr.Stroke ();
 			cr.Color = text_color;
 			cr.MoveTo (x + line_size + offset_x, y - 0.01);
-			cr.ShowPangoText (GameTypesDescription.GetLocalized (Translations, GameTypes.Memory));
+			cr.ShowPangoText (GameTypesDescription.GetLocalized (GameTypes.Memory));
 			cr.Stroke ();
 
 			cr.Color = math_color;
@@ -110,7 +108,7 @@ namespace gbrainy.Core.Views
 			cr.Stroke ();
 			cr.Color = text_color;
 			cr.MoveTo (x + line_size + offset_x, y - 0.01 + second_row);
-			cr.ShowPangoText (GameTypesDescription.GetLocalized (Translations, GameTypes.Calculation));
+			cr.ShowPangoText (GameTypesDescription.GetLocalized (GameTypes.Calculation));
 			cr.Stroke ();
 
 			x += space_hor;
@@ -120,7 +118,7 @@ namespace gbrainy.Core.Views
 			cr.Stroke ();
 			cr.Color = text_color;
 			cr.MoveTo (x + line_size + offset_x, y - 0.01);
-			cr.ShowPangoText (GameTypesDescription.GetLocalized (Translations, GameTypes.VerbalAnalogy));
+			cr.ShowPangoText (GameTypesDescription.GetLocalized (GameTypes.VerbalAnalogy));
 			cr.Stroke ();
 
 			cr.LineWidth = old_width;
@@ -273,8 +271,8 @@ namespace gbrainy.Core.Views
 			DrawLegend (cr, x + grid_offsetx, y + area_h + 0.06);
 			DrawGrid (cr, grid_x, grid_y);
 
-			DrawAxisDescription (cr, x + area_w + 0.01, 0.78, Translations.GetString ("Time"));
-			DrawAxisDescription (cr, 0, 0.03, Translations.GetString ("Score"));
+			DrawAxisDescription (cr, x + area_w + 0.01, 0.78, ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Time"));
+			DrawAxisDescription (cr, 0, 0.03, ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Score"));
 		}
 	}
 }
