@@ -21,6 +21,7 @@ using System;
 
 using gbrainy.Core.Main;
 using gbrainy.Core.Toolkit;
+using gbrainy.Core.Services;
 
 namespace gbrainy.Games.Calculation
 {
@@ -33,7 +34,7 @@ namespace gbrainy.Games.Calculation
 		double num, den, percentage, correct;
 
 		public override string Name {
-			get {return Translations.GetString ("Proportions");}
+			get {return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Proportions");}
 		}
 
 		public override GameTypes Type {
@@ -43,7 +44,7 @@ namespace gbrainy.Games.Calculation
 		public override string Question {
 			get {
 				return String.Format (
-					Translations.GetString ("What is {0}% of {1}/{2}? Answer {3}, {4}, {5} or {6}."), 
+					ServiceLocator.Instance.GetService <ITranslations> ().GetString ("What is {0}% of {1}/{2}? Answer {3}, {4}, {5} or {6}."), 
 					percentage, num, den, Answer.GetMultiOption (0), Answer.GetMultiOption (1), Answer.GetMultiOption (2), Answer.GetMultiOption (3));}
 		}
 
@@ -79,7 +80,7 @@ namespace gbrainy.Games.Calculation
 			options [options_next++] = correct;
 			options [options_next++] = percentage / 70d * num / den;
 			options [options_next++] = percentage / 120d * num / den;
-			options [options_next] = percentage / 150d * num / den;
+			options [options_next++] = percentage / 150d * num / den;
 
 			random_indices = new ArrayListIndicesRandom (options_cnt);
 			random_indices.Initialize ();
@@ -127,7 +128,7 @@ namespace gbrainy.Games.Calculation
 			gr.SetPangoLargeFontSize ();
 
 			gr.MoveTo (0.1, 0.15);
-			gr.ShowPangoText (Translations.GetString ("Choose one of the following:"));
+			gr.ShowPangoText (ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Choose one of the following:"));
 		}
 	}
 }
