@@ -75,9 +75,6 @@ namespace gbrainy.Games
 			typeof (PuzzleDice),
 			typeof (PuzzleTrains),
 			typeof (PuzzleRelatedNumbers),
-			typeof (PuzzleFindTheNumber),
-			typeof (PuzzleLargestDiameter),
-			typeof (PuzzleLargestArea)
 		};
 
 		static Type[] CalculationInternal = new Type[] 
@@ -92,9 +89,6 @@ namespace gbrainy.Games
 			typeof (CalculationAverage),
 			typeof (CalculationProportions),
 			typeof (CalculationRatio),
-			typeof (CalculationSelectedNumbers),
-			typeof (CalculationConsecutiveSum),
-
 		};
 
 		static Type[] MemoryInternal = new Type[] 
@@ -104,7 +98,7 @@ namespace gbrainy.Games
 			typeof (MemoryColouredText),
 			typeof (MemoryWords),
 			typeof (MemoryCountDots),
-			typeof (MemoryFaces),
+			typeof (MemoryFigures),
 			typeof (MemoryIndications),
 			typeof (MemoryNumbers),
 			typeof (MemoryFacts),
