@@ -20,27 +20,28 @@
 using System;
 
 using gbrainy.Core.Main;
+using gbrainy.Core.Services;
 
 namespace gbrainy.Games.Logic
 {
 	public class PuzzleCirclesSquare : Game
 	{
 		public override string Name {
-			get {return Translations.GetString ("Circles in a square");}
+			get {return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Circles in a square");}
 		}
 
 		public override string Question {
-			get {return Translations.GetString ("What is the maximum number of circles (as shown) that fit in the square below?");} 
+			get {return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("What is the maximum number of circles (as shown) that fit in the square below?");} 
 		}
 
 		public override string Tip {
-			get { return Translations.GetString ("You can fit more than 64 circles.");}
+			get { return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("You can fit more than 64 circles.");}
 		}
 
 		public override string Rationale {
 			get {
 				// Translators: {0} is replaced always by 0.1340
-				return String.Format (Translations.GetString ("Using the above layout {0} units of height are gained per row leaving enough space for an additional row."), 0.1340);
+				return String.Format (ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Using the above layout {0} units of height are gained per row leaving enough space for an additional row."), 0.1340);
 			}
 		}
 
@@ -74,9 +75,11 @@ namespace gbrainy.Games.Logic
 			gr.Stroke ();
 
 			gr.MoveTo (first_x + 0.2, first_y - 0.06 - space_fromrect);
-			gr.ShowPangoText (Translations.GetString ("8 units"));
+			gr.ShowPangoText (ServiceLocator.Instance.GetService <ITranslations> ().GetString ("8 units"));
 			gr.Stroke ();
 
+
+
 			//  ---
 			//	 |
 			//	 |
@@ -93,7 +96,7 @@ namespace gbrainy.Games.Logic
 			gr.Stroke ();
 
 			gr.MoveTo (first_x - space_fromrect - 0.07, first_y + 0.3);
-			gr.ShowPangoText (Translations.GetString ("8 units"), false, -1, 270 * Math.PI/180);
+			gr.ShowPangoText (ServiceLocator.Instance.GetService <ITranslations> ().GetString ("8 units"), false, -1, 270 * Math.PI/180);
 			gr.Stroke ();
 
 			// Sample circle
@@ -112,7 +115,7 @@ namespace gbrainy.Games.Logic
 			gr.Stroke ();
 
 			gr.MoveTo (first_x + 0.65, first_y - 0.04 - space_fromcircle);
-			gr.ShowPangoText (Translations.GetString ("1 unit"));
+			gr.ShowPangoText (ServiceLocator.Instance.GetService <ITranslations> ().GetString ("1 unit"));
 			gr.Stroke ();
 
 			//  ---
@@ -131,7 +134,7 @@ namespace gbrainy.Games.Logic
 			gr.Stroke ();
 
 			gr.MoveTo (first_x + 0.65 - space_fromcircle - 0.08, first_y + 0.15);
-			gr.ShowPangoText (Translations.GetString ("1 unit"), false, -1, 270 * Math.PI/180);
+			gr.ShowPangoText (ServiceLocator.Instance.GetService <ITranslations> ().GetString ("1 unit"), false, -1, 270 * Math.PI/180);
 			gr.Stroke ();
 
 			if (Answer.Draw == false)
