@@ -17,10 +17,10 @@
  * Boston, MA 02111-1307, USA.
  */
 
-using Mono.Unix;
 using System;
 
 using gbrainy.Core.Main;
+using gbrainy.Core.Services;
 
 namespace gbrainy.Games.Logic
 {
@@ -38,7 +38,7 @@ namespace gbrainy.Games.Logic
 		GameType gametype;
 
 		public override string Name {
-			get {return Catalog.GetString ("Counting");}
+			get {return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Counting");}
 		}
 
 		public override string Question {
@@ -61,17 +61,17 @@ namespace gbrainy.Games.Logic
 				var = 2 + random.Next (5);
 				total = 50 + random.Next (100);
 				question = String.Format (
-					Catalog.GetPluralString ("We have a {0} meter piece of fabric.", "We have a {0} meters piece of fabric.", total),
+					ServiceLocator.Instance.GetService <ITranslations> ().GetPluralString ("We have a {0} meter piece of fabric.", "We have a {0} meters piece of fabric.", total),
 					total);
 				question += " ";
 				question += String.Format (
-					Catalog.GetPluralString ("Machine A takes {0} second to cut 1 meter of this fabric. How many seconds does Machine A take to cut the entire piece of fabric into 1 meter pieces?",
+					ServiceLocator.Instance.GetService <ITranslations> ().GetPluralString ("Machine A takes {0} second to cut 1 meter of this fabric. How many seconds does Machine A take to cut the entire piece of fabric into 1 meter pieces?",
 						"Machine A takes {0} seconds to cut 1 meter of this fabric. How many seconds does Machine A take to cut the entire piece of fabric into 1 meter pieces?"
 						, var), var);
 				answer = String.Format (
 					// Translators: {0} is always a number greater than 1
-					Catalog.GetString ("With the {0} cut, Machine A creates two 1 meter pieces."), (total - 1));
-	
+					ServiceLocator.Instance.GetService <ITranslations> ().GetString ("With the {0} cut, Machine A creates two 1 meter pieces."), (total - 1));
+
 				ans = (total - 1) * var;
 				break;
 
@@ -79,12 +79,19 @@ namespace gbrainy.Games.Logic
 				total = 20 + random.Next (20);
 				ans = 4 * total - 4;
 				question = String.Format (
-					// Translators: {0} is always a number greater than 20
-					Catalog.GetString ("A fence is built to enclose a square shaped region. {0} fence poles are used in each side of the square. How many fence poles are used in total?"),
+					// Translators: {0} is a number
+					ServiceLocator.Instance.GetService <ITranslations> ().GetPluralString (
+						"A fence is built to enclose a square shaped region. {0} fence pole is used in each side of the square. How many fence poles are used in total?",
+						"A fence is built to enclose a square shaped region. {0} fence poles are used in each side of the square. How many fence poles are used in total?",
+						total),
 					total);
-					// Translators: {0} is always a number greater than 20
+					// Translators: {0} is a number
 				answer = String.Format (
-					Catalog.GetString ("There are {0} fence poles since the poles on the corners of the square are shared."), ans);
+					ServiceLocator.Instance.GetService <ITranslations> ().GetPluralString (
+						"There is {0} fence pole since the poles on the corners of the square are shared.",
+						"There are {0} fence poles since the poles on the corners of the square are shared.",
+						ans)
+					, ans);
 				break;
 
 			case GameType.Present:
@@ -92,16 +99,24 @@ namespace gbrainy.Games.Logic
 				total = present + 2;
 				ans = total;
 				question = String.Format (
-					// Translators: {0} is always a number greater than 5
-					Catalog.GetString ("Wrapping an anniversary present costs one euro. The anniversary present costs {0} euros more than the cost to wrap it. How much does it cost to both purchase and wrap the present?"),
+					// Translators: {0} is a number
+					ServiceLocator.Instance.GetService <ITranslations> ().GetPluralString (
+						"Wrapping an anniversary present costs one monetary unit. The anniversary present costs {0} monetary unit more than the cost to wrap it. How much does it cost to both purchase and wrap the present?",
+						"Wrapping an anniversary present costs one monetary unit. The anniversary present costs {0} monetary units more than the cost to wrap it. How much does it cost to both purchase and wrap the present?",
+						present),
 					present);
-				answer = Catalog.GetString ("Individually, the present costs one euro more to purchase than to wrap.");
+
+				answer = String.Format (
+					ServiceLocator.Instance.GetService <ITranslations> ().GetPluralString (
+					"It is the cost of the present, {0} monetary unit, plus one monetary unit of the wrapping.",
+					"It is the cost of the present, {0} monetary units, plus one monetary unit of the wrapping.",
+					present + 1), present + 1);
 				break;
 			default:
 				throw new Exception ("Unexpected value");
 			}
 
-			right_answer = (ans).ToString ();
+			Answer.Correct = (ans).ToString ();
 		}
 
 		public override void Draw (CairoContextEx gr, int area_width, int area_height, bool rtl)
@@ -113,12 +128,14 @@ namespace gbrainy.Games.Logic
 			} else {
 				if (gametype == GameType.Fence)
 				{
-					double x105, y105;
-					const double x = 0.35, y = 0.2;
+					double x105, y105, y;
+					const double x = 0.35;
 					const double figure_size = 0.4;
 
 					x105 = figure_size * Math.Cos (105 * Math.PI / 180);
 					y105 = figure_size * Math.Sin (105 * Math.PI / 180);
+
+					y = (1 - y105) / 2;
 					gr.MoveTo (x, y);
 					gr.LineTo (x + x105, y + y105);
 					gr.LineTo (x + x105 + figure_size, y + y105);
