@@ -55,17 +55,17 @@ namespace gbrainy.Games.Logic
 		Figure [] figure_answers;
 
 		public override string Name {
-			get {return Translations.GetString ("Figures");}
+			get {return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Figures");}
 		}
 
 		public override string Question {
-			get {return String.Format (Translations.GetString ("What is the next logical sequence of objects in the last column? Answer {0}, {1} or {2}."),
+			get {return String.Format (ServiceLocator.Instance.GetService <ITranslations> ().GetString ("What is the next logical sequence of objects in the last column? Answer {0}, {1} or {2}."),
 				Answer.GetMultiOption (0), Answer.GetMultiOption (1), Answer.GetMultiOption (2));}
 		}
 
 		public override string Rationale {
 			get {
-				return Translations.GetString ("It is the only combination that you can build with the given elements without repeating them.");
+				return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("It is the only combination that you can build with the given elements without repeating them.");
 			}
 		}
 
@@ -117,6 +117,10 @@ namespace gbrainy.Games.Logic
 				drawable_area.DataEx = Answer.GetMultiOption (ans);
 				container.AddChild (drawable_area);
 
+				if (answer_indices[ans] == good_answer) {
+					Answer.SetMultiOptionAnswer (ans, Answer.GetFigureName (ans));
+				}
+
 				drawable_area.DrawEventHandler += delegate (object sender, DrawEventArgs e)
 				{
 					double width = total_width / possible_answers;
@@ -133,7 +137,6 @@ namespace gbrainy.Games.Logic
 					e.Context.Stroke ();
 				};
 			}
-			Answer.SetMultiOptionAnswer (answer_indices[good_answer], Answer.GetFigureName (answer_indices[good_answer]));
 		}
 
 		static void DrawFigure (CairoContextEx gr, double x, double y, Figure figure)
@@ -189,7 +192,7 @@ namespace gbrainy.Games.Logic
 			}
 
 			gr.MoveTo (0.08, 0.45);
-			gr.ShowPangoText (Translations.GetString ("Choose one of the following:"));
+			gr.ShowPangoText (ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Choose one of the following:"));
 			gr.Stroke ();
 		}
 	}
