@@ -18,48 +18,47 @@
  */
 
 using gbrainy.Core.Main;
+using gbrainy.Core.Services;
 
 namespace gbrainy.Games.Logic
 {
 	public class PuzzleSquareSheets : Game
 	{
-		const double width = 0.4, height = 0.4; 
-
 		public override string Name {
-			get {return Translations.GetString ("Square sheets");}
+			get {return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Square sheets");}
 		}
 
 		public override string Question {
-			get {return Translations.GetString ("What is the minimum number of square sheets of paper of any size required to create the figure? Lines indicate frontiers between different sheets.");}
+			get {return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("What is the minimum number of square sheets of paper of any size required to create the figure? Lines indicate frontiers between different sheets.");}
 		}
 
 		public override string Tip {
-			get { return Translations.GetString ("The sheets should overlap.");}
+			get { return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("The sheets should overlap.");}
 		}
 
 		public override string Rationale {
 			get {
 				// Translators: the translated version should not take more characters that the English original
-				return Translations.GetString ("A full sized square of paper (yellow), a 3/4 of the whole size square of paper (blue) in the bottom right corner, another 3/4 square of paper (green) in the top left corner and a 1/4 square of paper (red) in the top left corner.");
+				return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("A full sized square of paper, a 3/4 of the whole size square of paper in the bottom right corner, another 3/4 square of paper in the top left corner and a 1/4 square of paper in the top left corner.");
 			}
 		}
 
-		public override bool UsesColors {
-			get { return true;}
-		}
-
 		protected override void Initialize ()
 		{
 			Answer.Correct = "4";
 		}
 
-		void DrawQuestion (CairoContextEx gr, double x, double y)
+		public override void Draw (CairoContextEx gr, int area_width, int area_height, bool rtl)
 		{
+			double x = DrawAreaX + 0.2, y = DrawAreaY + 0.2, width = 0.4, height = 0.4;
+
+			base.Draw (gr, area_width, area_height, rtl);
+
 			gr.Rectangle (x, y, width, height);
 			gr.Stroke ();
 
 			gr.MoveTo (x, y + 0.1);
-			gr.LineTo (x + width, y + 0.1);  // Container square
+			gr.LineTo (x + width, y + 0.1);  // First horizontal
 			gr.Stroke ();
 
 			gr.MoveTo (x, y + 0.3);
@@ -74,52 +73,6 @@ namespace gbrainy.Games.Logic
 			gr.LineTo (x + 0.3, y + height - 0.1);  // Second vertical
 			gr.Stroke ();
 		}
-
-		void DrawAnswer (CairoContextEx gr, double x, double y)
-		{
-			ColorPalette palette = new ColorPalette (Translations);
-			gr.Save ();
-
-			// A full sized square of paper
-			gr.Color = palette.Cairo (ColorPalette.Id.Yellow);
-			gr.Rectangle (x, y, width, height);
-			gr.Fill ();
-			gr.Stroke ();
-
-			// 3/4 of the whole size square of paper in the bottom right corner
-			gr.Color = palette.Cairo (ColorPalette.Id.Blue);
-			double w = 3d/4d * width;
-			double h = 3d/4d * height;
-			gr.Rectangle (x + (width - w), y + (height - h), w, h);
-			gr.Fill ();
-			gr.Stroke ();
-
-			// 3/4 square of paper in the top left corner
-			gr.Color = palette.Cairo (ColorPalette.Id.Green);
-			gr.Rectangle (x, y, 3d/4d * width, 3d/4d * height);
-			gr.Fill ();
-			gr.Stroke ();
-			
-			// 1/4 square of paper in the top left corner
-			gr.Color = palette.Cairo (ColorPalette.Id.Red);
-			gr.Rectangle (x, y, 1d/4d * width, 1d/4d * height);
-			gr.Fill ();
-			gr.Stroke ();
-
-			gr.Restore ();
-		}
-
-		public override void Draw (CairoContextEx gr, int area_width, int area_height, bool rtl)
-		{
-			double x = DrawAreaX + 0.2, y = DrawAreaY + 0.2;
-
-			base.Draw (gr, area_width, area_height, rtl);
-
-			if (Answer.Draw)
-				DrawAnswer (gr, x, y);
-
-			DrawQuestion (gr, x, y);
-		}
 	}
 }
 
