@@ -23,21 +23,16 @@ using NUnit.Framework;
 
 using gbrainy.Clients.Classical;
 using gbrainy.Core.Main;
-using gbrainy.Core.Services;
-using gbrainy.Core.Libraries;
 
 namespace gbrainy.Test.Clients.Classical
 {
 	[TestFixture]
 	public class CommandLineTest : UnitTestSupport
 	{
-		ITranslations translations;
-
 		[TestFixtureSetUp]
 		public void Construct ()
 		{
 			RegisterDefaultServices ();
-			translations = new TranslationsCatalog ();
 		}
 
 		[Test]
@@ -49,7 +44,7 @@ namespace gbrainy.Test.Clients.Classical
 			args = new string [1];
 			args [0] = "--norandom";
 
-			line = new CommandLine (translations, args);
+			line = new CommandLine (args);
 			Assert.AreEqual (true, line.RandomOrder);
 			line.Parse ();
 
@@ -62,7 +57,7 @@ namespace gbrainy.Test.Clients.Classical
 			const int game_cnt = 5; // number of games to pass as parameters
 			CommandLine line;
 			string [] args;
-			GameLocator [] games;
+			GameManager.GameLocator [] games;
 			GameManager gm = new GameManager ();
 			StringBuilder game_list = new StringBuilder ();
 			int [] candidates; // Stores the indexes of the games passed as parameters
@@ -77,7 +72,6 @@ namespace gbrainy.Test.Clients.Classical
 					continue;
 
 				Game game = (Game) Activator.CreateInstance (games[i].TypeOf, true);
-				game.Translations = translations;
 				game.Variant = games[i].Variant;
 
 				if (cand_idx > 0)
@@ -94,7 +88,7 @@ namespace gbrainy.Test.Clients.Classical
 			args [0] = "--customgame";
 			args [1] = game_list.ToString ();
 
-			line = new CommandLine (translations, args);
+			line = new CommandLine (args);
 			line.Parse ();
 
 			Assert.AreEqual (cand_idx, line.PlayList.Length);
